package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TDeliveryRecord;
import com.zehong.system.service.ITDeliveryRecordService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 配送记录Controller
 *
 * @author zehong
 * @date 2023-08-22
 */
@RestController
@RequestMapping("/system/recordn")
public class TDeliveryRecordController extends BaseController
{
    @Autowired
    private ITDeliveryRecordService tDeliveryRecordService;

    /**
     * 查询配送记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TDeliveryRecord tDeliveryRecord)
    {
        startPage();
        List<TDeliveryRecord> list = tDeliveryRecordService.selectTDeliveryRecordList(tDeliveryRecord);
        return getDataTable(list);
    }

    /**
     * 导出配送记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "配送记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TDeliveryRecord tDeliveryRecord)
    {
        List<TDeliveryRecord> list = tDeliveryRecordService.selectTDeliveryRecordList(tDeliveryRecord);
        ExcelUtil<TDeliveryRecord> util = new ExcelUtil<TDeliveryRecord>(TDeliveryRecord.class);
        return util.exportExcel(list, "配送记录数据");
    }

    /**
     * 获取配送记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{deliveryRecordId}")
    public AjaxResult getInfo(@PathVariable("deliveryRecordId") Long deliveryRecordId)
    {
        return AjaxResult.success(tDeliveryRecordService.selectTDeliveryRecordById(deliveryRecordId));
    }

    /**
     * 新增配送记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "配送记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDeliveryRecord tDeliveryRecord)
    {
        return toAjax(tDeliveryRecordService.insertTDeliveryRecord(tDeliveryRecord));
    }

    /**
     * 新增配送记录
     * @param tDeliveryRecord
     * @return
     */
    @PostMapping("/addRecord")
    public AjaxResult addRecord(@RequestBody TDeliveryRecord tDeliveryRecord)
    {
        return toAjax(tDeliveryRecordService.insertTDeliveryRecord(tDeliveryRecord));
    }


    /**
     * 修改配送记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "配送记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDeliveryRecord tDeliveryRecord)
    {
        return toAjax(tDeliveryRecordService.updateTDeliveryRecord(tDeliveryRecord));
    }

    /**
     * 删除配送记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "配送记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deliveryRecordIds}")
    public AjaxResult remove(@PathVariable Long[] deliveryRecordIds)
    {
        return toAjax(tDeliveryRecordService.deleteTDeliveryRecordByIds(deliveryRecordIds));
    }
}
